summaryrefslogtreecommitdiffstats
path: root/Http/Authentication/AuthenticationSuccessHandlerInterface.php
diff options
context:
space:
mode:
authorBernhard Schussek <bernhard.schussek@symfony-project.com>2011-03-13 19:16:56 +0100
committerBernhard Schussek <bernhard.schussek@symfony-project.com>2011-03-13 19:49:10 +0100
commit27a103510af2a2a730937e39db0530b57f9b507a (patch)
tree7973136ac2d2fccf1b5c79e12d1de6bafaa99935 /Http/Authentication/AuthenticationSuccessHandlerInterface.php
parent263ba4d42870ef5f991540c8b039c2472ba8b204 (diff)
downloadsymfony-security-27a103510af2a2a730937e39db0530b57f9b507a.zip
symfony-security-27a103510af2a2a730937e39db0530b57f9b507a.tar.gz
symfony-security-27a103510af2a2a730937e39db0530b57f9b507a.tar.bz2
Switched from Doctrine's EventManager implementation to the EventManager clone in Symfony2 (now called EventDispatcher again)
Diffstat (limited to 'Http/Authentication/AuthenticationSuccessHandlerInterface.php')
-rw-r--r--Http/Authentication/AuthenticationSuccessHandlerInterface.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/Http/Authentication/AuthenticationSuccessHandlerInterface.php b/Http/Authentication/AuthenticationSuccessHandlerInterface.php
index 30b5e26..d7f8488 100644
--- a/Http/Authentication/AuthenticationSuccessHandlerInterface.php
+++ b/Http/Authentication/AuthenticationSuccessHandlerInterface.php
@@ -2,7 +2,7 @@
namespace Symfony\Component\Security\Http\Authentication;
-use Symfony\Component\HttpKernel\Event\GetResponseEventArgs;
+use Symfony\Component\HttpKernel\Event\GetResponseEvent;
use Symfony\Component\Security\Core\Authentication\Token\TokenInterface;
use Symfony\Component\HttpFoundation\Request;
@@ -22,12 +22,12 @@ interface AuthenticationSuccessHandlerInterface
* is called by authentication listeners inheriting from
* AbstractAuthenticationListener.
*
* @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request
* @param TokenInterface $token
*
* @return Response the response to return
*/
- function onAuthenticationSuccess(GetResponseEventArgs $eventArgs, Request $request, TokenInterface $token);
+ function onAuthenticationSuccess(GetResponseEvent $event, Request $request, TokenInterface $token);
} \ No newline at end of file
@@ -22,12 +22,12 @@ interface AuthenticationSuccessHandlerInterface
* AbstractAuthenticationListener.
*
- * @param GetResponseEventArgs $eventArgs the "onCoreSecurity" event, this event always
+ * @param GetResponseEvent $event the "onCoreSecurity" event, this event always
* has the kernel as target
* @param Request $request